@@ -1,6 +1,7 @@
 use super::{conv, AsNative};
 use std::{mem, ops::Range};
 
+// has to match `Temp::binding_sizes`
 const WORD_SIZE: usize = 4;
 
 impl Default for super::CommandState {
@@ -63,15 +64,15 @@ impl super::CommandState {
     fn make_sizes_buffer_update<'a>(
         &self,
         stage: naga::ShaderStage,
-        result_sizes: &'a mut Vec<wgt::BufferSize>,
-    ) -> Option<(u32, &'a [wgt::BufferSize])> {
+        result_sizes: &'a mut Vec<u32>,
+    ) -> Option<(u32, &'a [u32])> {
         let stage_info = &self.stage_infos[stage];
         let slot = stage_info.sizes_slot?;
         result_sizes.clear();
         for br in stage_info.sized_bindings.iter() {
             // If it's None, this isn't the right time to update the sizes
             let size = self.storage_buffer_length_map.get(br)?;
-            result_sizes.push(*size);
+            result_sizes.push(size.get().min(!0u32 as u64) as u32);
         }
         Some((slot as _, result_sizes))
     }
@@ -372,13 +373,13 @@ impl crate::CommandEncoder<super::Api> for super::CommandEncoder {
                 let at_descriptor = descriptor.stencil_attachment().unwrap();
                 at_descriptor.set_texture(Some(&at.target.view.raw));
 
-                let load_action = if at.depth_ops.contains(crate::AttachmentOps::LOAD) {
+                let load_action = if at.stencil_ops.contains(crate::AttachmentOps::LOAD) {
                     mtl::MTLLoadAction::Load
                 } else {
                     at_descriptor.set_clear_stencil(at.clear_value.1);
                     mtl::MTLLoadAction::Clear
                 };
-                let store_action = if at.depth_ops.contains(crate::AttachmentOps::STORE) {
+                let store_action = if at.stencil_ops.contains(crate::AttachmentOps::STORE) {
                     mtl::MTLStoreAction::Store
                 } else {
                     mtl::MTLStoreAction::DontCare
