@@ -697,6 +697,7 @@ impl super::Instance {
                     .contains(vk::FormatFeatureFlags::DEPTH_STENCIL_ATTACHMENT)
             },
             non_coherent_map_mask: phd_capabilities.properties.limits.non_coherent_atom_size - 1,
+            can_present: true,
         };
 
         let capabilities = crate::Capabilities {
@@ -825,6 +826,7 @@ impl super::Adapter {
                 spv::Capability::Image1D,
                 spv::Capability::ImageQuery,
                 spv::Capability::DerivativeControl,
+                spv::Capability::SampledCubeArray,
                 //Note: this is requested always, no matter what the actual
                 // adapter supports. It's not the responsibility of SPV-out
                 // translation to handle the storage support for formats.
@@ -836,6 +838,10 @@ impl super::Adapter {
                 spv::WriterFlags::DEBUG,
                 self.instance.flags.contains(crate::InstanceFlags::DEBUG),
             );
+            flags.set(
+                spv::WriterFlags::LABEL_VARYINGS,
+                self.phd_capabilities.properties.vendor_id != crate::auxil::db::qualcomm::VENDOR,
+            );
             spv::Options {
                 lang_version: (1, 0),
                 flags,
@@ -857,7 +863,7 @@ impl super::Adapter {
             vendor_id: self.phd_capabilities.properties.vendor_id,
             downlevel_flags: self.downlevel_flags,
             private_caps: self.private_caps.clone(),
-            _timestamp_period: self.phd_capabilities.properties.limits.timestamp_period,
+            timestamp_period: self.phd_capabilities.properties.limits.timestamp_period,
             render_passes: Mutex::new(Default::default()),
             framebuffers: Mutex::new(Default::default()),
         });
@@ -1018,6 +1024,10 @@ impl crate::Adapter<super::Api> for super::Adapter {
         &self,
         surface: &super::Surface,
     ) -> Option<crate::SurfaceCapabilities> {
+        if !self.private_caps.can_present {
+            return None;
+        }
+
         let queue_family_index = 0; //TODO
         match surface.functor.get_physical_device_surface_support(
             self.raw,
